@@ -29,16 +29,18 @@ import javax.annotation.PostConstruct;
 import javax.enterprise.context.ApplicationScoped;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
-import javax.inject.Named;
 
+import org.drools.scenariosimulation.api.model.Background;
 import org.drools.scenariosimulation.api.model.ScenarioSimulationModel;
 import org.drools.scenariosimulation.api.model.ScenarioWithIndex;
+import org.drools.scenariosimulation.api.model.ScesimModelDescriptor;
+import org.drools.scenariosimulation.api.model.Settings;
 import org.drools.scenariosimulation.api.model.Simulation;
-import org.drools.scenariosimulation.api.model.SimulationDescriptor;
 import org.drools.scenariosimulation.backend.runner.ScenarioJunitActivator;
 import org.drools.scenariosimulation.backend.util.ImpossibleToFindDMNException;
 import org.drools.scenariosimulation.backend.util.ScenarioSimulationXMLPersistence;
 import org.drools.workbench.screens.scenariosimulation.backend.server.util.ScenarioSimulationBuilder;
+import org.drools.workbench.screens.scenariosimulation.model.FactMappingValidationError;
 import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModelContent;
 import org.drools.workbench.screens.scenariosimulation.model.SimulationRunResult;
 import org.drools.workbench.screens.scenariosimulation.service.DMNTypeService;
@@ -71,12 +73,12 @@ import org.uberfire.ext.editor.commons.backend.service.SaveAndRenameServiceImpl;
 import org.uberfire.ext.editor.commons.service.CopyService;
 import org.uberfire.ext.editor.commons.service.DeleteService;
 import org.uberfire.ext.editor.commons.service.RenameService;
-import org.uberfire.io.IOService;
 import org.uberfire.java.nio.file.FileAlreadyExistsException;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.workbench.events.ResourceOpenedEvent;
 
 import static org.drools.scenariosimulation.api.model.ScenarioSimulationModel.Type;
+import static org.drools.scenariosimulation.api.model.ScenarioSimulationModel.Type.DMN;
 
 @Service
 @ApplicationScoped
@@ -84,59 +86,45 @@ public class ScenarioSimulationServiceImpl
         extends KieService<ScenarioSimulationModelContent>
         implements ScenarioSimulationService {
 
-    @Inject
-    @Named("ioStrategy")
-    private IOService ioService;
-
-    @Inject
-    private CopyService copyService;
-
-    @Inject
-    private DeleteService deleteService;
-
-    @Inject
-    private RenameService renameService;
-
-    @Inject
-    private Event<ResourceOpenedEvent> resourceOpenedEvent;
-
-    @Inject
-    private ScenarioSimulationResourceTypeDefinition resourceTypeDefinition;
-
-    @Inject
-    private CommentedOptionFactory commentedOptionFactory;
-
-    @Inject
-    private SaveAndRenameServiceImpl<ScenarioSimulationModel, Metadata> saveAndRenameService;
-
-    @Inject
-    private DataModelService dataModelService;
-
-    @Inject
-    private ScenarioRunnerService scenarioRunnerService;
-
-    @Inject
-    private User user;
-
-    @Inject
-    private POMService pomService;
-
-    @Inject
-    private KieModuleService kieModuleService;
+    private static final String KIE_VERSION = "kie.version";
+    private static final String JUNIT_ACTIVATOR_PACKAGE_NAME = "testscenario";
+    private static final String ORG_DROOLS = "org.drools";
+    private static final String ORG_KIE = "org.kie";
+    private static final String ORG_JBPM = "org.jbpm";
 
     @Inject
     protected ScenarioSimulationBuilder scenarioSimulationBuilder;
-
     @Inject
     protected DMNTypeService dmnTypeService;
-
+    @Inject
+    protected ScenarioValidationService scenarioValidationService;
+    @Inject
+    private CopyService copyService;
+    @Inject
+    private DeleteService deleteService;
+    @Inject
+    private RenameService renameService;
+    @Inject
+    private Event<ResourceOpenedEvent> resourceOpenedEvent;
+    @Inject
+    private ScenarioSimulationResourceTypeDefinition resourceTypeDefinition;
+    @Inject
+    private CommentedOptionFactory commentedOptionFactory;
+    @Inject
+    private SaveAndRenameServiceImpl<ScenarioSimulationModel, Metadata> saveAndRenameService;
+    @Inject
+    private DataModelService dataModelService;
+    @Inject
+    private ScenarioRunnerService scenarioRunnerService;
+    @Inject
+    private User user;
+    @Inject
+    private POMService pomService;
+    @Inject
+    private KieModuleService kieModuleService;
     private SafeSessionInfo safeSessionInfo;
-
     private Properties props = new Properties();
 
-    private static final String KIE_VERSION = "kie.version";
-    private static final String junitActivatorPackageName = "testscenario";
-
     {
         String propertyFileName = "kie.properties";
         try {
@@ -161,12 +149,16 @@ public class ScenarioSimulationServiceImpl
 
     @Override
     public SimulationRunResult runScenario(final Path path,
-                                           final SimulationDescriptor simulationDescriptor,
-                                           final List<ScenarioWithIndex> scenarios) {
+                                           final ScesimModelDescriptor simulationDescriptor,
+                                           final List<ScenarioWithIndex> scenarios,
+                                           final Settings settings,
+                                           final Background background) {
         return scenarioRunnerService.runTest(user.getIdentifier(),
                                              path,
                                              simulationDescriptor,
-                                             scenarios);
+                                             scenarios,
+                                             settings,
+                                             background);
     }
 
     @Override
@@ -181,6 +173,8 @@ public class ScenarioSimulationServiceImpl
     public Path create(Path context, String fileName, ScenarioSimulationModel content, String comment, Type type, String value) {
         try {
             content.setSimulation(scenarioSimulationBuilder.createSimulation(context, type, value));
+            content.setBackground(scenarioSimulationBuilder.createBackground(context, type, value));
+            content.setSettings(scenarioSimulationBuilder.createSettings(context, type, value));
             final org.uberfire.java.nio.file.Path nioPath = Paths.convert(context).resolve(fileName);
             final Path newPath = Paths.convert(nioPath);
 
@@ -205,13 +199,13 @@ public class ScenarioSimulationServiceImpl
         try {
             final String content = ioService.readAllString(Paths.convert(path));
 
-            ScenarioSimulationModel scenarioSimulationModel = unmarshalInternal(content);
-            Simulation simulation = scenarioSimulationModel.getSimulation();
-            if(simulation != null && Type.DMN.equals(simulation.getSimulationDescriptor().getType())) {
+            final ScenarioSimulationModel scenarioSimulationModel = unmarshalInternal(content);
+            final Settings settings = scenarioSimulationModel.getSettings();
+            if (settings != null && DMN.equals(settings.getType())) {
                 try {
-                    dmnTypeService.initializeNameAndNamespace(simulation,
+                    dmnTypeService.initializeNameAndNamespace(settings,
                                                               path,
-                                                              simulation.getSimulationDescriptor().getDmnFilePath());
+                                                              settings.getDmnFilePath());
                 } catch (ImpossibleToFindDMNException e) {
                     // this error is not thrown so user can fix the file path manually
                     logger.error(e.getMessage(), e);
@@ -338,6 +332,11 @@ public class ScenarioSimulationServiceImpl
         return saveAndRenameService.saveAndRename(path, newFileName, metadata, content, comment);
     }
 
+    @Override
+    public List<FactMappingValidationError> validate(Simulation simulation, Settings settings, Path path) {
+        return scenarioValidationService.validateSimulationStructure(simulation, settings, path);
+    }
+
     protected void createActivatorIfNotExist(Path context) {
         KieModule kieModule = kieModuleService.resolveModule(context);
 
@@ -352,7 +351,7 @@ public class ScenarioSimulationServiceImpl
             removeOldActivatorIfExists(activatorPath, kieModule);
 
             ioService.write(activatorPath,
-                            ScenarioJunitActivator.ACTIVATOR_CLASS_CODE.apply(junitActivatorPackageName),
+                            ScenarioJunitActivator.ACTIVATOR_CLASS_CODE.apply(JUNIT_ACTIVATOR_PACKAGE_NAME),
                             commentedOptionFactory.makeCommentedOption(""));
         }
     }
@@ -362,7 +361,7 @@ public class ScenarioSimulationServiceImpl
         Path junitActivatorPackagePath = Paths.convert(getJunitActivatorPackagePath(rootPackage));
         Package junitActivatorPackage = kieModuleService.resolvePackage(junitActivatorPackagePath);
         if (junitActivatorPackage == null) {
-            junitActivatorPackage = kieModuleService.newPackage(rootPackage, junitActivatorPackageName);
+            junitActivatorPackage = kieModuleService.newPackage(rootPackage, JUNIT_ACTIVATOR_PACKAGE_NAME);
         }
         return junitActivatorPackage;
     }
@@ -446,26 +445,29 @@ public class ScenarioSimulationServiceImpl
     }
 
     protected org.uberfire.java.nio.file.Path getJunitActivatorPackagePath(Package rootModulePackage) {
-        return internalGetPath(rootModulePackage, junitActivatorPackageName);
+        return internalGetPath(rootModulePackage, JUNIT_ACTIVATOR_PACKAGE_NAME);
     }
 
     protected List<GAV> getOldDependencies() {
-        return Arrays.asList(new GAV("org.drools", "drools-wb-scenario-simulation-editor-api", null),
-                             new GAV("org.drools", "drools-wb-scenario-simulation-editor-backend", null));
+        return Arrays.asList(new GAV(ORG_DROOLS, "drools-wb-scenario-simulation-editor-api", null),
+                             new GAV(ORG_DROOLS, "drools-wb-scenario-simulation-editor-backend", null));
     }
 
     protected List<GAV> getDependencies(String kieVersion) {
-        return Arrays.asList(new GAV("org.drools", "drools-scenario-simulation-api", kieVersion),
-                             new GAV("org.drools", "drools-scenario-simulation-backend", kieVersion),
-                             new GAV("org.drools", "drools-compiler", kieVersion),
+        return Arrays.asList(new GAV(ORG_DROOLS, "drools-scenario-simulation-api", kieVersion),
+                             new GAV(ORG_DROOLS, "drools-scenario-simulation-backend", kieVersion),
+                             new GAV(ORG_DROOLS, "drools-compiler", kieVersion),
                              // needed to compile guided decision table
-                             new GAV("org.drools", "drools-workbench-models-guided-dtable", kieVersion),
-                             new GAV("org.kie", "kie-dmn-feel", kieVersion),
-                             new GAV("org.kie", "kie-dmn-api", kieVersion),
-                             new GAV("org.kie", "kie-dmn-core", kieVersion));
+                             new GAV(ORG_DROOLS, "drools-workbench-models-guided-dtable", kieVersion),
+                             // needed in case of BPMN file in the project, but not used directly by scesim
+                             new GAV(ORG_JBPM, "jbpm-bpmn2", kieVersion),
+                             // DMN dependencies
+                             new GAV(ORG_KIE, "kie-dmn-feel", kieVersion),
+                             new GAV(ORG_KIE, "kie-dmn-api", kieVersion),
+                             new GAV(ORG_KIE, "kie-dmn-core", kieVersion));
     }
 
-    protected ScenarioSimulationModel unmarshalInternal(String content) {
+    protected ScenarioSimulationModel unmarshalInternal(String content) throws Exception {
         return ScenarioSimulationXMLPersistence.getInstance().unmarshal(content);
     }
 
